@@ -20,7 +20,7 @@
 #include "headertest.h"
 
 #include <QDebug>
-#include <qtest.h>
+#include <QTest>
 
 #include <kmime_headers.h>
 
